Collecting certain datasets without filters will likely result in a large object being returned. Given
that their is a limit on the number of rows that can be returned from the Vicmap geoserver (70,000) data will be
paginated; which essentially means that multiple queries will be sent with the data bound together at the end. This
process may take a while to run, thus it is recommended to filter large datasets before collection.