Learn R Programming

VicmapR (version 0.2.3)

geom_col_name: Get Column Information

Description

geom_col_name returns a single value for the name of the geometry column for the WFS layer selected in the vicmap_promise object (e.g. SHAPE). This column will become the geometry column when using collect(). feature_cols() provides a vector of all column names for the WFS layer selected in the vicmap_promise object and get_col_df() returns a data.frame with the column names and their XML schema string datatypes.

Usage

geom_col_name(x)

feature_cols(x)

get_col_df(x)

Value

character/data.frame

Arguments

x

object of class vicmap_promise

Examples

Run this code
# \donttest{
# Return the name of the geometry column
vicmap_query(layer = "open-data-platform:hy_watercourse") %>% 
  geom_col_name()
 # }
# \donttest{
# Return the column names as a character vector
vicmap_query(layer = "open-data-platform:hy_watercourse") %>% 
  feature_cols()
# }   
# \donttest{
# Return a data.frame of the columns and their XML schema string datatypes
try(
vicmap_query(layer = "open-data-platform:hy_watercourse") %>% 
  get_col_df()
  )
 # }

Run the code above in your browser using DataLab